@@ -776,7 +776,7 @@ updategeom(void)
 	panes[PaneFeeds].y = 0;
 	panes[PaneFeeds].height = win.height - 1; /* space for statusbar */
 
-	/* NOTE: updatesidebar() must happen before updategeometry for the
+	/* NOTE: updatesidebar() must happen before this function for the
 	   remaining width */
 	if (!panes[PaneFeeds].hidden) {
 		w = win.width - panes[PaneFeeds].width;
@@ -1256,6 +1256,29 @@ feeds_reloadall(void)
 	updatetitle();
 }
 
+int
+getsidebarwidth(void)
+{
+	struct feed *feed;
+	static char text[1024];
+	int i, len, width = 0;
+
+	for (i = 0; i < nfeeds; i++) {
+		feed = &feeds[i];
+
+		snprintf(text, sizeof(text), "%s (%lu/%lu)",
+		         feed->name, feed->totalnew, feed->total);
+		len = colw(text);
+		if (len > width)
+			width = len;
+
+		if (onlynew && feed->totalnew == 0)
+			continue;
+	}
+
+	return width;
+}
+
 void
 updatesidebar(int onlynew)
 {
@@ -1263,15 +1286,17 @@ updatesidebar(int onlynew)
 	struct row *row;
 	struct feed *feed;
 	size_t i, nrows;
-	int len, width;
+	int oldwidth;
 
 	p = &panes[PaneFeeds];
 
 	if (!p->rows)
 		p->rows = ecalloc(sizeof(p->rows[0]), nfeeds + 1);
 
+	oldwidth = p->width;
+	p->width = getsidebarwidth();
+
 	nrows = 0;
-	width = 0;
 	for (i = 0; i < nfeeds; i++) {
 		feed = &feeds[i];
 
@@ -1280,24 +1305,18 @@ updatesidebar(int onlynew)
 		row->bold = (feed->totalnew > 0);
 		row->data = feed;
 
-		len = colw(pane_row_text(p, row));
-		if (len > width)
-			width = len;
-
 		if (onlynew && feed->totalnew == 0)
 			continue;
 
 		nrows++;
 	}
-
-	if (p->width != width) {
-		for (i = 0; i < PaneLast; i++)
-			panes[i].dirty = 1;
-	} else {
-		p->dirty = 1;
-	}
 	p->nrows = nrows;
-	p->width = width;
+
+	if (p->width != oldwidth)
+		updategeom();
+	else
+		p->dirty = 1;
+
 	if (!p->nrows)
 		p->pos = 0;
 	else if (p->pos >= p->nrows)
@@ -1402,6 +1421,7 @@ mousereport(int button, int release, int x, int y)
 				break;
 			pane_setpos(p, pos);
 			if (i == PaneFeeds) {
+				readurls();
 				row = pane_row_get(p, pos);
 				f = (struct feed *)row->data;
 				feeds_set(f);
@@ -1450,15 +1470,10 @@ feed_row_format(struct pane *p, struct row *row)
 
 	feed = (struct feed *)row->data;
 
-	if (p->width) {
-		len = snprintf(counts, sizeof(counts), "(%lu/%lu)",
-		               feed->totalnew, feed->total);
-		utf8pad(bufw, sizeof(bufw), feed->name, p->width - len, ' ');
-		snprintf(text, sizeof(text), "%s%s", bufw, counts);
-	} else {
-		snprintf(text, sizeof(text), "%s (%lu/%lu)",
-		         feed->name, feed->totalnew, feed->total);
-	}
+	len = snprintf(counts, sizeof(counts), "(%lu/%lu)",
+	               feed->totalnew, feed->total);
+	utf8pad(bufw, sizeof(bufw), feed->name, p->width - len, ' ');
+	snprintf(text, sizeof(text), "%s%s", bufw, counts);
 
 	return text;
 }
@@ -1711,8 +1726,8 @@ main(int argc, char *argv[])
 	if ((devnullfd = open("/dev/null", O_WRONLY)) < 0)
 		err(1, "open: /dev/null");
 
-	updatetitle();
 	updatesidebar(onlynew);
+	updatetitle();
 	init();
 	draw();
 
@@ -1886,8 +1901,9 @@ nextpage:
 			break;
 		case 'o': /* feeds: load, items: plumb url */
 		case '\n':
+			p = &panes[selpane];
 			if (selpane == PaneFeeds && panes[PaneFeeds].nrows) {
-				p = &panes[selpane];
+				readurls();
 				row = pane_row_get(p, p->pos);
 				f = (struct feed *)row->data;
 				feeds_set(f);
@@ -1897,7 +1913,6 @@ nextpage:
 				updatesidebar(onlynew);
 				updatetitle();
 			} else if (selpane == PaneItems && panes[PaneItems].nrows) {
-				p = &panes[PaneItems];
 				row = pane_row_get(p, p->pos);
 				item = (struct item *)row->data;
 				markread(p, p->pos, p->pos, 1);
@@ -1910,7 +1925,7 @@ nextpage:
 		case 'y': /* yank: pipe TSV line to yank url to clipboard */
 		case 'E': /* yank: pipe TSV line to yank enclosure to clipboard */
 			if (selpane == PaneItems && panes[PaneItems].nrows) {
-				p = &panes[PaneItems];
+				p = &panes[selpane];
 				row = pane_row_get(p, p->pos);
 				item = (struct item *)row->data;
 				switch (ch) {
@@ -1933,7 +1948,7 @@ nextpage:
 		case 'r': /* mark item as read */
 		case 'u': /* mark item as unread */
 			if (selpane == PaneItems && panes[PaneItems].nrows) {
-				p = &panes[PaneItems];
+				p = &panes[selpane];
 				markread(p, p->pos, p->pos, ch == 'r');
 			}
 			break;
